import os,os.path,string,commands
import cherrypy
#import re
from Common import config,DetConfig
import pluginCondDBPyInterface as CondDB
from CondCore.Utilities import iovInspector as inspect

from cherrypy.lib import static
import datetime
import pickle
class IOV(object):
    def __init__(self,configfilepath):
        self.__config=config.Config()
        self.__config.from_ini(configfilepath)
        self.__authpath=self.__config.iov.auth_path
        self.__datasavedir=self.__config.iov.datasave_dir
        #print 'detector_config ',self.__config.iov.detector_conf
        self.__detconfig=DetConfig.DetConfig(self.__config.iov.detector_conf)
        self.__logdb=str(self.__config.iov.log_conn)

    @cherrypy.expose
    def index(self):
        """Top level page
        """
        #print self.__authpath
        return "IOVPAGE!!!"
        

    
    def __getconnectstr(self,det,service,schema,viacache):
        """Assemble full connect string with given parameters
        """
        if len(viacache)==0:
            connect_str=''
            if (service.find(":"))==-1 :
               connect_str='oracle://'
            connect_str+=service+'/'+schema          
        else:            
            knownservices=self.__detconfig.services(det)
            connect_str=''
            if '/'.join([service,schema]) not in knownservices:
               return ''
            servletname=self.__detconfig.serviceToServlet(det,service)
            connect_str='frontier://cmsfrontier.cern.ch:8000/'+servletname+'/'+schema
        print "connect to ", connect_str
        if len(connect_str)==0:
            return "Application Server Error: requested service "+service+" "+schema+"is not configured"
#
        return connect_str
    
    @cherrypy.expose
    def getTags(self,det,service,schema,viacache):
        """Get list of tags
        """
        connect_str=self.__getconnectstr(det,service,schema,viacache)
        print connect_str

       	rdbms = CondDB.RDBMS()
        rdbms.setLogger(self.__logdb)
        db = rdbms.getDB(connect_str)              
        tags = db.allTags()
        result=''
        for entry in tags.split():
            iov = db.iov(entry)
            log = db.lastLogEntry(entry).getState()
            print log
            result += entry.strip() + " " + str(iov.size()) + ';'
        iov=0
        db=0
        return result
        
    @cherrypy.expose
    def getIOVForTag(self,det,service,schema,tag, since, till, detail, viacache):
        """Get iov info for given tag
        """
        sum = len(detail)>0
        if (0==len(till)) :
            since = 0
            till = 0
        
        connect_str=self.__getconnectstr(det,service,schema,viacache)

        rdbms = CondDB.RDBMS()
        rdbms.setLogger(self.__logdb)
        db = rdbms.getDB(connect_str)
        # this one still crashes if tag is not present...
        iov = inspect.Iov(db,tag,long(since),long(till))
        if (sum) : ret = pickle.dumps(iov.summaries())
        else :
            ret = pickle.dumps(iov.list())
        iov=0
        db=0
        return ret

    @cherrypy.expose
    def getWhatForTag(self,det,service,schema,tag,viacache):
        rdbms = CondDB.RDBMS()
        connect_str=self.__getconnectstr(det,service,schema,viacache)
        db = rdbms.getDB(connect_str)
        what = pickle.dumps(inspect.extractorWhat(db,tag))
        db=0
        return what

    @cherrypy.expose
    def getTrendForTag(self,det,service,schema,tag, since, till, extractor, viacache):
        """Get iov info for given tag
        """
        what = pickle.loads(extractor)
        if (0==len(till)) :
            since = 0
            till = 0
        
        connect_str=self.__getconnectstr(det,service,schema,viacache)

        rdbms = CondDB.RDBMS()
        rdbms.setLogger(self.__logdb)
        db = rdbms.getDB(connect_str)
        # this one still crashes if tag is not present...
        iov = inspect.Iov(db,tag,long(since),long(till))
        ret = pickle.dumps(iov.trend(what))
        iov=0
        db=0
        return ret
    
    @cherrypy.expose
    def getPlot(self):
        """a test to understand few thing
        """
	filename = "bha.jpg"
        datafile=os.path.join(self.__datasavedir,filename)
    	print datafile
        print os.path.basename(datafile)
        return static.serve_file(datafile, "application/x-download", "attachment",os.path.basename(datafile))

